@@ -1,6 +1,6 @@
 import asyncio
 import argparse
-#import os
+
 import numpy as np
 import json
 
@@ -8,28 +8,26 @@ from joule.utils.localnumpypipe import LocalNumpyPipe
 from nilm.readers import capture
 from nilm.filters import prep, sinefit, reconstructor
 
-#import pdb
-#import matplotlib.pyplot as plt
+SAMPLE_FREQ = 3000
 
-SAMPLE_FREQ=3000
 
-def run(meter,duration):
-    """ Given an array of magnetic sensors [mchannels] 
+def run(meter, duration):
+    """ Given an array of magnetic sensors [mchannels]
         and a single electric sensor [echannel],
-        read [duration] seconds of data 
+        read [duration] seconds of data
         and return prep using identity reconstruction matrix"""
-    #figure out how many rows of data to capture
-    nrows = duration*3000 #noncontact sample frequency
+    # figure out how many rows of data to capture
+    nrows = duration * 3000  # noncontact sample frequency
 
     num_sensors = len(meter['sensors']['current']['sensor_indices'])
 
-    #pipes to connect modules
+    # pipes to connect modules
     npipe_raw = LocalNumpyPipe("raw", layout="int16_8")
-    npipe_iv = LocalNumpyPipe("iv", layout="float32_%d" % (1+num_sensors))
+    npipe_iv = LocalNumpyPipe("iv", layout="float32_%d" % (1 + num_sensors))
     npipe_iv2 = LocalNumpyPipe("iv", layout=npipe_iv.layout)
     npipe_iv.subscribe(npipe_iv2)
     #   prep is P1,Q1 for every magnetic sensor
-    prep_layout="float32_%d" % (num_sensors*2)
+    prep_layout = "float32_%d" % (num_sensors * 2)
     npipe_prep = LocalNumpyPipe("prep", layout=prep_layout)
     npipe_zc = LocalNumpyPipe("prep", layout="float32_3")
 
@@ -43,8 +41,6 @@ def run(meter,duration):
     npipe_zc.subscribe(tpipe_zc)
     """
 
-
-    tasks = []
     # capture reader
     capture_args = argparse.Namespace(
         meter=meter['name'],
@@ -53,36 +49,35 @@ def run(meter,duration):
 
     my_capture = capture.Capture()
     capture_future = asyncio.ensure_future(
-        my_capture.run( capture_args,
-                        npipe_raw, meter=meter))
+        my_capture.run(capture_args,
+                       npipe_raw, meter=meter))
 
     # reconstructor (needed to integrate voltage signal)
     reconstructor_configs = json.dumps({
         'noncontact': True,
         'm_indices': meter['sensors']['current']['sensor_indices'],
-        'e_indices':meter['sensors']['voltage']['sensor_index'],
+        'e_indices': meter['sensors']['voltage']['sensor_index'],
         'voltage_matrix': [1.0],
         'current_matrix': np.eye(num_sensors).tolist(),
         'nominal_frequency': 60,
         'sampling_frequency': 3000,
         'max_gap': 1,
         'integrate': meter['sensors']['voltage']['digitally_integrate']
-        })
+    })
     my_reconstructor = reconstructor.Reconstructor()
     asyncio.ensure_future(
         my_reconstructor.run(
             argparse.Namespace(config=reconstructor_configs),
             {'raw': npipe_raw},
             {'iv': npipe_iv}))
-    
 
     # sinefit
     sinefit_configs = json.dumps({
-            'v_index': 1,
-            'min_amp': 10,
-            'min_freq': 55,
-            'frequency': 60,
-            'max_freq': 65})
+        'v_index': 1,
+        'min_amp': 10,
+        'min_freq': 55,
+        'frequency': 60,
+        'max_freq': 65})
     my_sinefit = sinefit.Sinefit()
     asyncio.ensure_future(
         my_sinefit.run(
@@ -94,7 +89,7 @@ def run(meter,duration):
     prep_configs = json.dumps({
         'nshift': 1,
         'nharm': 1,
-        'current_indices': list(range(2,num_sensors+2)),
+        'current_indices': list(range(2, num_sensors + 2)),
         'rotations': np.zeros(num_sensors).tolist(),
         'scale_factor': 1.0,
         'merge': True})
@@ -151,4 +146,3 @@ def run(meter,duration):
     plt.show()
     """
     return prep_data['data']
-        
