@@ -34,7 +34,7 @@ Inputs:
 Outputs (eg for 3 phase contact merged):
 
     'iv'             float32 <V_A, I_A, V_B, I_B> eg for 2 phase
-    'zero_crossings' float32 <freq, qmp, phase>
+    'zero_crossings' float32 <freq, amp, phase>
     'prep'           float32 <P1A, P1B, P1C, ... Q7A, Q7B, Q7C>
 
 Arguments
@@ -78,7 +78,6 @@ class RawToPrep(FilterModule):
         # configure logger
         logger = logging.getLogger()
         logger.setLevel(logging.WARN)
-        
         try:
             meters = meter.load_meters(parsed_args.config_file,
                                        parsed_args.cal_dir)
@@ -211,7 +210,7 @@ class RawToPrep(FilterModule):
 
     def _build_sinefit_configs(self, meter):
         config = {}
-        config['v_index'] = meter['sensors']['voltage']['sensor_index']+1
+        config['v_index']=1 #V_A for contact or 'V' for noncontact
         config['min_amp'] = 10
         config['min_freq'] = 40
         config['frequency'] = 60
